@@ -1,6 +1,6 @@
 #!/bin/sh
 #    libvirt-uri.sh - Automatically switch default libvirt URI for user
-#    Copyright (C) 2015 Canonical Ltd.
+#    Copyright (C) 2023 Canonical Ltd.
 #
 #    Authors: Stefan Bader <stefan.bader@canonical.com>
 #
@@ -17,11 +17,5 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 LIBVIRT_DEFAULT_URI="qemu:///system"
-if [ -f /proc/xen/capabilities ]; then
-	if [ "$(cat /proc/xen/capabilities)" = "control_d" ]; then
-		LIBVIRT_DEFAULT_URI="xen:///"
-	fi
-fi
 
 export LIBVIRT_DEFAULT_URI
-
